@@ -287,6 +287,7 @@ class IosBaseCompiler(RouterCompiler):
             ipv4_loopback_subnet = netaddr.IPNetwork("0.0.0.0/32")
             ipv4_cidr = address_prefixlen_to_network(ipv4_address, ipv4_loopback_subnet.prefixlen)
         if node.ip.use_ipv6:
+            print "here"
             ipv6_node = self.anm['ipv6'].node(node)
             ipv6_address = address_prefixlen_to_network(ipv6_node.loopback, 128)
 
@@ -328,13 +329,15 @@ class IosBaseCompiler(RouterCompiler):
         node.bgp.lo_interface = self.lo_interface
         super(IosBaseCompiler, self).bgp(node)
 
-        ipv4_address = self.anm['ipv4'].node(node).loopback
-        ipv4_loopback_subnet = netaddr.IPNetwork("0.0.0.0/32")
-        ipv4_cidr = address_prefixlen_to_network(ipv4_address, ipv4_loopback_subnet.prefixlen)
-        node.bgp.ipv4_advertise_subnets = [ipv4_cidr]
-        ipv6_node = self.anm['ipv6'].node(node)
-        ipv6_address = address_prefixlen_to_network(ipv6_node.loopback, 128)
-        node.bgp.ipv6_advertise_subnets = [ipv6_address]
+        if node.ip.use_ipv4:
+            ipv4_address = self.anm['ipv4'].node(node).loopback
+            ipv4_loopback_subnet = netaddr.IPNetwork("0.0.0.0/32")
+            ipv4_cidr = address_prefixlen_to_network(ipv4_address, ipv4_loopback_subnet.prefixlen)
+            node.bgp.ipv4_advertise_subnets = [ipv4_cidr]
+        if node.ip.use_ipv6:
+            ipv6_node = self.anm['ipv6'].node(node)
+            ipv6_address = address_prefixlen_to_network(ipv6_node.loopback, 128)
+            node.bgp.ipv6_advertise_subnets = [ipv6_address]
 
     def ospf(self, node):
         super(IosBaseCompiler, self).ospf(node)
